#!/usr/bin/env perl
use strict;
use warnings;
use DBI;
use DateTime::Format::Strptime;


#declare variables
my $db; my $user; my $sth; my $dbh; my $sth2; my $filedischarge; my $filestage; my $timestring; my $t;
my $line; my $inputtz; my $timezone; my $station; my $time; my $discharge; my $stage; my $obstype;
my $table1; my $table2; my $stmt;

#Postgres database interface code specifying database and table to link to along with commands
$filedischarge = $ARGV[0];
$filestage = $ARGV[1];
$db =$ARGV[2];
$table1=$ARGV[3];
$table2=$ARGV[4];
$user = $ARGV[5];
#$pass = "pass";
#$host="localhost";

#connect to postgres database
$dbh = DBI->connect( "dbi:Pg:dbname=$db", "$user" ) or die $DBI::errstr;

#lines below commented out since temporary processing tables
#are now deleted/cleared in the ver.ingest.csh script which calls this perl script
##empty contents of temporary processing tables
#$sth = $dbh->prepare(
#"DELETE FROM $table1"
#) or die $dbh->errstr;
#$sth->execute()or die $DBI::errstr;
#
#$sth = $dbh->prepare(
#"DELETE FROM $table2"
#) or die $dbh->errstr;
#$sth->execute()or die $DBI::errstr;

#prepare insert command for discharge using dummy variables
$sth = $dbh->prepare(
"INSERT INTO $table1 (station, time, discharge, obstype) VALUES (?, ?, ?, ?)"
) or die $dbh->errstr;

#open CSV formatted USGS discharge file
	open(INPUT, $filedischarge) or die "Cannot open $filedischarge";
# Read the usgs report lines one by one keep units as cubic feet per second
	while($line = <INPUT>)
	{
		chomp($line);
		my ($agency, $station, $time, $inputtz, $discharge, $obstype) = split(',', $line);
#                $discharge = 0.0283168466 * $discharge;
#compute timezone offset of current data line based on input timezone
if ($inputtz =~ m/EDT/g){
        $timezone = '-4:00';
} elsif ($inputtz =~ m/CDT/g){
        $timezone = '-5:00';
} elsif ($inputtz =~ m/MDT/g){
        $timezone = '-6:00';
} elsif ($inputtz =~ m/PDT/g){
        $timezone = '-7:00';
} elsif ($inputtz =~ m/AKDT/g){
        $timezone = '-8:00';
} elsif ($inputtz =~ m/ADT/g){
        $timezone = '-8:00';
} elsif ($inputtz =~ m/HDT/g){
        $timezone = '-9:00';
} elsif ($inputtz =~ m/EST/g) {
        $timezone = '-5:00';
} elsif ($inputtz =~ m/CST/g) {
        $timezone = '-6:00';
} elsif ($inputtz =~ m/MST/g) {
        $timezone = '-7:00';
} elsif ($inputtz =~ m/PST/g) {
        $timezone = '-8:00';
} elsif ($inputtz =~ m/AKST/g) {
        $timezone = '-9:00';
} elsif ($inputtz =~ m/AST/g) {
        $timezone = '-9:00';
} elsif ($inputtz =~ m/HST/g) {
        $timezone = '-10:00'; }


#convert date and time from local to UTC
my $format = DateTime::Format::Strptime->new(
   pattern   => '%Y-%m-%d %H:%M',
   time_zone => $timezone,
   on_error  => 'croak',);
$timestring = $time;
$t = $format->parse_datetime($timestring);
$t->set_time_zone('UTC');
$timestring = $t->strftime("%Y-%m-%d %H:%M");

#insert data into postgres database
$sth->execute($station, $timestring, $discharge, $obstype)or die $DBI::errstr;
if($sth < 0){
print $DBI::errstr; }
}

#prepare insert command for stage using dummy variables
$sth = $dbh->prepare(
"INSERT INTO $table2 (station, time, stage, obstype) VALUES (?, ?, ?, ?)"
) or die $dbh->errstr;

#open CSV formatted USGS stage file
        open(INPUT, $filestage) or die "Cannot open $filestage";
# Read the usgs report lines one by one keep units as feet
        while($line = <INPUT>)
        {
                chomp($line);
                my ($agency, $station, $time, $inputtz, $stage, $obstype) = split(',', $line);
#                $stage = 0.3048 * $stage;
#compute timezone offset of current data line based on input timezone
if ($inputtz =~ m/EDT/g){
        $timezone = '-4:00';
} elsif ($inputtz =~ m/CDT/g){
        $timezone = '-5:00';
} elsif ($inputtz =~ m/MDT/g){
        $timezone = '-6:00';
} elsif ($inputtz =~ m/PDT/g){
        $timezone = '-7:00';
} elsif ($inputtz =~ m/AKDT/g){
        $timezone = '-8:00';
} elsif ($inputtz =~ m/ADT/g){
        $timezone = '-8:00';
} elsif ($inputtz =~ m/HDT/g){
        $timezone = '-9:00';
} elsif ($inputtz =~ m/EST/g) {
        $timezone = '-5:00';
} elsif ($inputtz =~ m/CST/g) {
        $timezone = '-6:00';
} elsif ($inputtz =~ m/MST/g) {
        $timezone = '-7:00';
} elsif ($inputtz =~ m/PST/g) {
        $timezone = '-8:00';
} elsif ($inputtz =~ m/AKST/g) {
        $timezone = '-9:00';
} elsif ($inputtz =~ m/AST/g) {
        $timezone = '-9:00';
} elsif ($inputtz =~ m/HST/g) {
        $timezone = '-10:00'; }

#convert date and time from local to UTC
my $format = DateTime::Format::Strptime->new(
   pattern   => '%Y-%m-%d %H:%M',
   time_zone => $timezone,
   on_error  => 'croak',);
$timestring = $time;
$t = $format->parse_datetime($timestring);
$t->set_time_zone('UTC');
$timestring = $t->strftime("%Y-%m-%d %H:%M");


#insert data into postgres database
$sth->execute($station, $timestring, $stage, $obstype)or die $DBI::errstr;
if($sth < 0){
print $DBI::errstr; }
}

close(INPUT);
	
$dbh->disconnect();



