#!/bin/csh

date >> /hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/start.end.time.txt

#define name of permanent tables that will hold USGS flood-related gauge data
#based on three methods of detection
set finaltabler = 'testflood_usgs_recurrence'
set finaltablef = 'testflood_usgs_floodstage'
set finaltableh = 'testflood_usgs_hourlyrise'
set finaltableff = 'testflashflood_usgs'



#define name of table holding static USGS gauge characteristic info
set usgstable = 'usgs_gauges'
#define names of temporary processing tables 
#(discharge only, stage only, and joint discharge and stage, hourly rate of rise in feet/hour)
set table1 = 'testdischarge_temp'
set table1id = 'testdischarge_temp.id'
set table1_id_seq = 'testdischarge_temp_id_seq'

set table2 = 'teststage_temp'
set table2id = 'teststage_temp.id'
set table2_id_seq = 'teststage_temp_id_seq'

set table3 = 'testjoint_temp'
set table3id = 'testjoint_temp.id'
set table3_id_seq = 'testjoint_temp_id_seq'

set table3s = 'testjoint_tempstation'
set table3sid = 'testjoint_tempstation.id'
set table3s_id_seq = 'testjoint_tempstation_id_seq'

set table3sm = 'testjoint_tempstationmaxmin'
set table3smid = 'testjoint_tempstationmaxmin.id'
set table3sm_id_seq = 'testjoint_tempstationmaxmin_id_seq'

set table3d = 'testjoint_delta'
set table3did = 'testjoint_delta.id'
set table3d_id_seq = 'testjoint_delta_id_seq'

set table4 = 'testhourlyrise_temp'
set table4id = 'testhourlyrise_temp.id'
set table4_id_seq = 'testhourlyrise_temp_id_seq'




#define database and user names
set database = 'verification'
set user = 'hpc'

#remove old temporary processing tables 
/usr/bin/psql -U $user -d $database -c "drop table $table1;"
/usr/bin/psql -U $user -d $database -c "drop table $table2;"
/usr/bin/psql -U $user -d $database -c "drop table $table3;"
/usr/bin/psql -U $user -d $database -c "drop table $table3s;"
/usr/bin/psql -U $user -d $database -c "drop table $table3sm;"
/usr/bin/psql -U $user -d $database -c "drop table $table3d;"
/usr/bin/psql -U $user -d $database -c "drop table $table4;"


#create new temporary processing tables (since they are new they will
#be empty and will have their id numbers reset to a starting value of 1

/usr/bin/psql -U $user -d $database -c "CREATE SEQUENCE $table1_id_seq;"
/usr/bin/psql -U $user -d $database -c "CREATE TABLE $table1 (id bigint NOT NULL DEFAULT nextval('$table1_id_seq'),station bigint NOT NULL,time timestamp NOT NULL,discharge float NOT NULL,obstype varchar(6) NOT NULL,PRIMARY KEY (id));"
/usr/bin/psql -U $user -d $database -c "ALTER SEQUENCE $table1_id_seq OWNED BY $table1id;"

/usr/bin/psql -U $user -d $database -c "CREATE SEQUENCE $table2_id_seq;"
/usr/bin/psql -U $user -d $database -c "CREATE TABLE $table2 (id bigint NOT NULL DEFAULT nextval('$table2_id_seq'),station bigint NOT NULL,time timestamp NOT NULL,stage float NOT NULL,obstype varchar(6) NOT NULL,PRIMARY KEY (id));"
/usr/bin/psql -U $user -d $database -c "ALTER SEQUENCE $table2_id_seq OWNED BY $table2id;"

/usr/bin/psql -U $user -d $database -c "CREATE SEQUENCE $table3_id_seq;"
/usr/bin/psql -U $user -d $database -c "CREATE TABLE $table3 (id bigint NOT NULL DEFAULT nextval('$table3_id_seq'),station bigint NOT NULL,time timestamp NOT NULL,  discharge float NOT NULL, dobstype varchar(6) NOT NULL,stage float NOT NULL,sobstype varchar(6) NOT NULL,PRIMARY KEY (id));"
/usr/bin/psql -U $user -d $database -c "ALTER SEQUENCE $table3_id_seq OWNED BY $table3id;"

/usr/bin/psql -U $user -d $database -c "CREATE SEQUENCE $table3s_id_seq;"
/usr/bin/psql -U $user -d $database -c "CREATE TABLE $table3s (id bigint NOT NULL DEFAULT nextval('$table3s_id_seq'),station bigint NOT NULL,time timestamp NOT NULL,  discharge float NOT NULL, dobstype varchar(6) NOT NULL,stage float NOT NULL,sobstype varchar(6) NOT NULL,drainagearea float, contribarea float, PRIMARY KEY (id));"
/usr/bin/psql -U $user -d $database -c "ALTER SEQUENCE $table3s_id_seq OWNED BY $table3sid;"

/usr/bin/psql -U $user -d $database -c "CREATE SEQUENCE $table3sm_id_seq;"
/usr/bin/psql -U $user -d $database -c "CREATE TABLE $table3sm (id bigint NOT NULL DEFAULT nextval('$table3sm_id_seq'),station bigint NOT NULL,time timestamp NOT NULL,  discharge float NOT NULL, dobstype varchar(6) NOT NULL, maxmindischarge float NOT NULL, stage float NOT NULL,sobstype varchar(6) NOT NULL, maxminstage float NOT NULL, drainagearea float, contribarea float, PRIMARY KEY (id));"
/usr/bin/psql -U $user -d $database -c "ALTER SEQUENCE $table3sm_id_seq OWNED BY $table3smid;"

/usr/bin/psql -U $user -d $database -c "CREATE SEQUENCE $table3d_id_seq;"
/usr/bin/psql -U $user -d $database -c "CREATE TABLE $table3d (id bigint NOT NULL DEFAULT nextval('$table3d_id_seq'),gauge bigint NOT NULL, maxmindischarge float NOT NULL, maxminstage float NOT NULL, PRIMARY KEY (id));"
/usr/bin/psql -U $user -d $database -c "ALTER SEQUENCE $table3d_id_seq OWNED BY $table3did;"

/usr/bin/psql -U $user -d $database -c "CREATE SEQUENCE $table4_id_seq;"
/usr/bin/psql -U $user -d $database -c "CREATE TABLE $table4 (id bigint NOT NULL DEFAULT nextval('$table4_id_seq'),station bigint NOT NULL,time timestamp NOT NULL,  hourlyrise float NOT NULL,  hourlyriseold float NOT NULL, maxminstage float NOT NULL,PRIMARY KEY (id));"
/usr/bin/psql -U $user -d $database -c "ALTER SEQUENCE $table4_id_seq OWNED BY $table4id;"


#list HUC's that contain gauge data to be processed
set hucnumber = ('08')


#loop over all HUC's that contain gauge data needing to be processed
set count = 1
while ($count <= $#hucnumber)
#remove old data files in preparation for execution of script
rm -f /hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/TEMP.DATA/usgs.data.discharge.txt
rm -f /hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/TEMP.DATA/usgs.data.discharge.stripped.txt
rm -f /hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/TEMP.DATA/usgs.data.stage.txt
rm -f /hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/TEMP.DATA/usgs.data.stage.stripped.txt


#set starttime = `date -u --date="-48 hours" +%Y'-'%m'-'%dT%H':'%M`
#set endtime = `date -u --date="-0 hours" +%Y'-'%m'-'%dT%H':'%M`

set starttime = '2014-06-29T00:00'
set psqlstarttime = '2014-06-29T00:00'
set endtime = '2014-06-29T23:59'

#download USGS discharge reports from previous day
#ONLY DOWNLOAD BASINS LESS THAN 2000 SQ KM (772 Sq Mi)...this will speed up processing...
#this is okay since we are interested in flash floods....not likely to occur on basins very large basins
#This limit is ALSO used farther down
wget "http://waterservices.usgs.gov/nwis/iv/?format=rdb&huc=$hucnumber[$count]&startDT=$starttime&endDT=$endtime&parameterCd=00060&drainAreaMax=772" -O /hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/TEMP.DATA/usgs.data.discharge.txt

#now preprocess file
cd /hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/TEMP.DATA/
#remove header
grep USGS usgs.data.discharge.txt | grep -v '#' > usgs.data.discharge.stripped.txt

#change non-numeric entries in observation column to -999
sed -i "s/\*\*\*/-999/g" usgs.data.discharge.stripped.txt
sed -i "s/Eqp/-999/g" usgs.data.discharge.stripped.txt
sed -i "s/Rat/-999/g" usgs.data.discharge.stripped.txt
sed -i "s/Ice/-999/g" usgs.data.discharge.stripped.txt
sed -i "s/ZFl/-999/g" usgs.data.discharge.stripped.txt
sed -i "s/Mnt/-999/g" usgs.data.discharge.stripped.txt
sed -i "s/Dis/-999/g" usgs.data.discharge.stripped.txt
sed -i "s/Dry/-999/g" usgs.data.discharge.stripped.txt
sed -i "s/Fld/-999/g" usgs.data.discharge.stripped.txt
sed -i "s/Pr/-999/g" usgs.data.discharge.stripped.txt
sed -i "s/Bkw/-999/g" usgs.data.discharge.stripped.txt
sed -i "s/Ssn/-999/g" usgs.data.discharge.stripped.txt
sed -i "s/--/-999/g" usgs.data.discharge.stripped.txt

#change from tab separated to comma separated file
sed -i 's/\t/,/g' usgs.data.discharge.stripped.txt

#replace three commas with a single comma.  This can occur due to non-consistent use of tab separators in file
#along with presence of multiple discharge or stage columns

##WARNING WARNING.......this processing needs to be improved.  Right now the code will use the
#first discharge or stage column it comes to.  Sometimes however, that may be an undefined column
#or a backup type of measurement.  The code should be made more intelligent such that it picks
#the primary measurement or looks for a non-undefined value among all options for that gauge
#in the data file.
sed -i "s/,,,/,/g" usgs.data.discharge.stripped.txt


#now perform for USGS stream stage (height) data
#download USGS stage reports from previous day
#ONLY DOWNLOAD BASINS LESS THAN 2000 SQ KM (772 Sq Mi)...this will speed up processing...
#this is okay since we are interested in flash floods....not likely to occur on basins very large basins
#This limit is ALSO used farther down
wget "http://waterservices.usgs.gov/nwis/iv/?format=rdb&huc=$hucnumber[$count]&startDT=$starttime&endDT=$endtime&parameterCd=00065&drainAreaMax=772" -O /hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/TEMP.DATA/usgs.data.stage.txt

#now preprocess file
cd /hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/TEMP.DATA/
#remove header
grep USGS usgs.data.stage.txt | grep -v '#' > usgs.data.stage.stripped.txt

#change non-numeric entries in observation column to -999
sed -i "s/\*\*\*/-999/g" usgs.data.stage.stripped.txt
sed -i "s/Eqp/-999/g" usgs.data.stage.stripped.txt
sed -i "s/Rat/-999/g" usgs.data.stage.stripped.txt
sed -i "s/Ice/-999/g" usgs.data.stage.stripped.txt
sed -i "s/ZFl/-999/g" usgs.data.stage.stripped.txt
sed -i "s/Mnt/-999/g" usgs.data.stage.stripped.txt
sed -i "s/Dis/-999/g" usgs.data.stage.stripped.txt
sed -i "s/Dry/-999/g" usgs.data.stage.stripped.txt
sed -i "s/Fld/-999/g" usgs.data.stage.stripped.txt
sed -i "s/Pr/-999/g" usgs.data.stage.stripped.txt
sed -i "s/Bkw/-999/g" usgs.data.stage.stripped.txt
sed -i "s/Ssn/-999/g" usgs.data.stage.stripped.txt
sed -i "s/--/-999/g" usgs.data.stage.stripped.txt

#change from tab separated to comma separated file
sed -i 's/\t/,/g' usgs.data.stage.stripped.txt

#Replace three commas with a single comma.  This can occur due to non-consistent use of tab separators in file
#along with presence of multiple discharge or stage columns
#
### WARNING WARNING.......this processing needs to be improved.  Right now the code will use the
#first discharge or stage column it comes to.  Sometimes however, that may be an undefined column
#or a backup type of measurement.  The code should be made more intelligent such that it picks
#the primary measurement or looks for a non-undefined value among all options for that gauge
#in the data file.
sed -i "s/,,,/,/g" usgs.data.stage.stripped.txt


#cd into location of perl scripts that decode USGS stream gauge reports
cd /hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/

##Process stream gauge reports, adding any that indicate flooding into postgres table
set filedischarge = '/hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/TEMP.DATA/usgs.data.discharge.stripped.txt'
set filestage = '/hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/TEMP.DATA/usgs.data.stage.stripped.txt'

#execute perl script to decode USGS stream gauge reports 
#example  perl flood.pl TEMP.DATA/usgs.data.discharge.stripped.txt TEMP.DATA/usgs.data.stage.stripped.txt verification discharge_temp stage_temp hpc
/usr/bin/perl flood.pl $filedischarge $filestage $database $table1 $table2 $user >&  /hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/flood.pl.out


#finished processing gauges from single HUC, return to top to process another HUC's worth of gauge data
@ count ++
end

#join discharge and stage reports into a single joint table
#depending on whether stage, discharge, or both types of obs are defined
#each gage may have one or two data entries (other would be -999...undefined)
/usr/bin/psql -U $user -d $database -c "insert into $table3 (station, time, discharge, dobstype, stage, sobstype) select $table1.station as stationid, $table1.time as obstime, $table1.discharge, $table1.obstype as dobstype, -999 as stage, 'NA' as sobstype from $table1 full outer join $table2 on ($table1.station=$table2.station) and ($table1.time=$table2.time) where $table1.station is not null and $table2.station is null union      select $table2.station as stationid, $table2.time as obstime, -999 as discharge, 'NA' as dobstype, $table2.stage, $table2.obstype as sobstype from $table1 full outer join $table2 on ($table1.station=$table2.station) and ($table1.time=$table2.time) where $table1.station is null and $table2.station is not null union    select $table2.station as stationid, $table2.time as obstime, $table1.discharge, $table1.obstype as dobstype, $table2.stage, $table2.obstype as sobstype from $table1 full outer join $table2 on ($table1.station=$table2.station) and ($table1.time=$table2.time) where $table1.station is not null and $table2.station is not null    order by stationid,obstime;"


#join preceding table with drainage area column to form more useful table
/usr/bin/psql -U $user -d $database -c "insert into $table3s (station,time,discharge,dobstype,stage,sobstype,drainagearea,contribarea) select A.station, A.time, A.discharge,A.dobstype,A.stage,A.sobstype,B.drainagearea,B.contribarea from $table3 as A LEFT OUTER JOIN $usgstable AS B ON A.station = B.id order by A.station, A.time;"


#create table which holds delta of stage and discharge over processing period
/usr/bin/psql -U $user -d $database -c "insert into $table3d (gauge,maxmindischarge,maxminstage) select station as gauge,max(discharge)-min(discharge) as maxmindischarge, max(stage)-min(stage) as maxminstage from $table3 group by station order by station;"

#join preceding table with delta (over period being processed in this script) discharge and stage info to form more useful table.  This will give a rough measurement of how much the stream rose/fell over the processing period.
/usr/bin/psql -U $user -d $database -c "insert into $table3sm (station,time,discharge,dobstype,maxmindischarge,stage,sobstype,maxminstage,drainagearea,contribarea) select station,time,discharge,dobstype,maxmindischarge,stage,sobstype,maxminstage,drainagearea,contribarea from $table3s,$table3d where station=gauge;"


#alter resulting table such that any NULL drainagearea or contribarea values (for stations in joint_table that don't exist in usgs_gauges) are set to -999
/usr/bin/psql -U $user -d $database -c "UPDATE $table3sm SET drainagearea = -999 WHERE drainagearea is null;"
/usr/bin/psql -U $user -d $database -c "UPDATE $table3sm SET contribarea = -999 WHERE contribarea is null;"



#draw on stage information to compute time and stage delta from one measurement to
#the next and select any gauges where stage rises by rate of >= 3.0 feet per hour at
#one observation time and >= 1ft/hr at a neighboring observation time using
#consecutive observations (could be only 15 minutes apart)
#i.e., two sets of slope computations are performed.  Filter out those with hourlyrise values
#greater than 200 ft/hr as erroneous values.  Filter out basins larger than 260 sq km (to reduce regulated basins).
#Also filter out basins where stage rises or falls by less than 2 feet over processing period.

/usr/bin/psql -U $user -d $database -c "insert into $table4 (station, time, hourlyrise,hourlyriseold,maxminstage) select station, time, slope, slopeold,maxminstage from (select station, time, drainagearea, contribarea, stage, timeint,stageint,stageint/((EXTRACT(hour FROM timeint))+(EXTRACT(MINUTE FROM timeint))/60) as slope,stageintold/((EXTRACT(hour FROM timeintold))+(EXTRACT(MINUTE FROM timeintold))/60) as slopeold,stageintold,maxminstage from (SELECT id, station, time, drainagearea, contribarea, stage,(time-LAG(time, 1) OVER (PARTITION BY station ORDER BY time ASC)) AS timeint,(LAG(time, 1) OVER (PARTITION BY station ORDER BY time ASC)-LAG(time, 2) OVER (PARTITION BY station ORDER BY time ASC)) AS timeintold, (stage-LAG(stage, 1) OVER (PARTITION BY station ORDER BY time ASC)) AS stageint, (LAG(stage, 1)OVER (PARTITION BY station ORDER BY time ASC) -LAG(stage, 2) OVER (PARTITION BY station ORDER BY time ASC)) AS stageintold,maxminstage FROM $table3sm) as intervals) as final where (((slope >= 3 and slopeold>=1.0) or (slope >= 1.0 and slopeold>=3)) and (slopeold<200 and slope<200) and ((drainagearea > 0 and drainagearea <= 260) or (contribarea > 0 and contribarea <= 260)) and (maxminstage>=2)) order by station,time;"

#execute commands to filter gauge reports such that only data from gauges in flood
#are inserted into flood table

# NOTE: basin drainage restrictions are used in statements below...but there
# are also basin restriction statements built into the usgs data download statements
# toward the beginning of this script.

#Uses NSSL-supplied flow associated with minor flood stage as flood/no flood dividing line
#WARNING....NSSL values of flow associated with flood stages and return periods are
#in units of cubic meters per second (CMS) while incoming USGS gauge observations are
#in units of cubic feet per second (CFS)...so adjustments have to be made below to compare the two.
/usr/bin/psql -U $user -d $database -c "insert into $finaltablef (station,name,time,lat,lon,regulation,drainagearea,contribarea,discharge,dobstype,stage,sobstype,detection,hourlyrise1,hourlyrise2, maxminstage,action, minor,moderate,major,q2,q5,q10,q25,q50,q100,q200,q500,risetime) select distinct on ($table3.station,$table3.time) $table3.station,$usgstable.name,$table3.time,$usgstable.lat, $usgstable.lon,$usgstable.regulation,$usgstable.drainagearea,$usgstable.contribarea, $table3.discharge,$table3.dobstype,$table3.stage, $table3.sobstype,'minor flood flow' as detection,'-999' as hourlyrise1, '-999' as hourlyrise2, '-999' as maxminstage, $usgstable.action*35.3146667,$usgstable.minor*35.3146667, $usgstable.moderate*35.3146667,$usgstable.major*35.3146667,$usgstable.q2*35.3146667, $usgstable.q5*35.3146667,$usgstable.q10*35.3146667,$usgstable.q25*35.3146667,$usgstable.q50*35.3146667,$usgstable.q100*35.3146667, $usgstable.q200*35.3146667,$usgstable.q500*35.3146667,$usgstable.risetime from $table3,$usgstable where (($table3.station = $usgstable.id) and ($table3.discharge >= $usgstable.minor*35.3146667) and ($usgstable.minor>0) and (($usgstable.drainagearea > 0 and $usgstable.drainagearea <= 260) or ($usgstable.contribarea > 0 and $usgstable.contribarea <= 260))) order by $table3.station,$table3.time,$table3.discharge desc;"

#uses NSSL-suplied flow associated with 2 year return period flow as flood/no flood dividing line
#WARNING....NSSL values of flow associated with flood stages and return periods are
#in units of cubic meters per second (CMS) while incoming USGS gauge observations are
#in units of cubic feet per second (CFS)...so adjustments have to be made below to compare the two.
/usr/bin/psql -U $user -d $database -c "insert into $finaltabler (station,name,time,lat,lon,regulation,drainagearea,contribarea,discharge,dobstype,stage,sobstype,detection,hourlyrise1,hourlyrise2,maxminstage,action,minor,moderate,major,q2,q5,q10,q25,q50,q100,q200,q500,risetime) select distinct on ($table3.station,$table3.time) $table3.station,$usgstable.name,$table3.time, $usgstable.lat,$usgstable.lon,$usgstable.regulation,$usgstable.drainagearea,$usgstable.contribarea, $table3.discharge,$table3.dobstype,$table3.stage,$table3.sobstype,'2yr recurrence flow' as detection,'-999' as hourlyrise1,'-999' as hourlyrise2,'-999' as maxminstage, $usgstable.action*35.3146667,$usgstable.minor*35.3146667, $usgstable.moderate*35.3146667,$usgstable.major*35.3146667,$usgstable.q2*35.3146667, $usgstable.q5*35.3146667,$usgstable.q10*35.3146667,$usgstable.q25*35.3146667,$usgstable.q50*35.3146667,$usgstable.q100*35.3146667,$usgstable.q200*35.3146667,$usgstable.q500*35.3146667, $usgstable.risetime from $table3,$usgstable where (($table3.station = $usgstable.id) and ($table3.discharge >= $usgstable.q2*35.3146667) and ($usgstable.q2 >0) and (($usgstable.drainagearea > 0 and $usgstable.drainagearea <= 260) or ($usgstable.contribarea > 0 and $usgstable.contribarea <= 260))) order by $table3.station,$table3.time,$table3.discharge desc;"


#uses rate of rise (from consecutive stage measurements) computed earlier in script
#as flood/no flood dividing line
#WARNING....NSSL values of flow associated with flood stages and return periods are
#in units of cubic meters per second (CMS) while incoming USGS gauge observations are
#in units of cubic feet per second (CFS)...so adjustments have to be made below to compare the two.

/usr/bin/psql -U $user -d $database -c "insert into $finaltableh (station,name,time,lat,lon,regulation,drainagearea,contribarea,discharge,dobstype,stage,sobstype,detection,hourlyrise1,hourlyrise2,maxminstage,action,minor,moderate,major,q2,q5,q10,q25,q50,q100,q200,q500,risetime) select distinct on ($table4.station,$table4.time) $table4.station,$usgstable.name,$table4.time, $usgstable.lat,$usgstable.lon,$usgstable.regulation,$usgstable.drainagearea,$usgstable.contribarea, $table3.discharge as discharge,$table3.dobstype as dobstype,$table3.stage as stage,$table3.sobstype as sobstype,'rate of rise' as detection,hourlyriseold as hourlyrise1, hourlyrise as hourlyrise2,maxminstage, $usgstable.action*35.3146667,$usgstable.minor*35.3146667, $usgstable.moderate*35.3146667,$usgstable.major*35.3146667,$usgstable.q2*35.3146667, $usgstable.q5*35.3146667,$usgstable.q10*35.3146667,$usgstable.q25*35.3146667,$usgstable.q50*35.3146667,$usgstable.q100*35.3146667,$usgstable.q200*35.3146667,$usgstable.q500*35.3146667, $usgstable.risetime from $table4,$usgstable,$table3 where (($table4.station = $usgstable.id) and ($table4.station = $table3.station) and ($table4.time=$table3.time) ) order by $table4.station,$table4.time,GREATEST ($table4.hourlyriseold,$table4.hourlyrise) desc;"


#cross check floodstage and recurrence tables with rate of rise table to isolate true flash floods...
#i.e., situations where stream most likely went out of bank (i.e., >=2 yr recurrence flow or minor flood stage)
#and where rate of rise and stage delta were large enough to indicate a flash flood quality to the event

#...insert stations that meet both recurrence and hourly rise criteria into flashflood_usgs table
/usr/bin/psql -U $user -d $database -c "insert into $finaltableff (station,name,time,lat,lon,regulation,drainagearea,contribarea,discharge,dobstype,stage,sobstype,detection,hourlyrise1,hourlyrise2,maxminstage,action,minor,moderate,major,q2,q5,q10,q25,q50,q100,q200,q500,risetime)  select A.station, A.name,A.time,A.lat,A.lon,A.regulation,A.drainagearea,A.contribarea,A.discharge,A.dobstype,A.stage,A.sobstype,'recurrence and rise' as method,B.hourlyrise1,B.hourlyrise2,B.maxminstage,A.action,A.minor,A.moderate,A.major,A.q2,A.q5,A.q10,A.q25,A.q50,A.q100,A.q200,A.q500,A.risetime from $finaltabler as A, $finaltableh as B where A.station=B.station and A.time=B.time and A.time >= '$psqlstarttime';"
#...insert stations that meet both flood stage and hourly rise criteria into flashflood_usgs table
/usr/bin/psql -U $user -d $database -c "insert into $finaltableff (station,name,time,lat,lon,regulation,drainagearea,contribarea,discharge,dobstype,stage,sobstype,detection,hourlyrise1,hourlyrise2,maxminstage,action,minor,moderate,major,q2,q5,q10,q25,q50,q100,q200,q500,risetime)  select A.station, A.name,A.time,A.lat,A.lon,A.regulation,A.drainagearea,A.contribarea,A.discharge,A.dobstype,A.stage,A.sobstype,'floodstage and rise' as method,B.hourlyrise1,B.hourlyrise2,B.maxminstage,A.action,A.minor,A.moderate,A.major,A.q2,A.q5,A.q10,A.q25,A.q50,A.q100,A.q200,A.q500,A.risetime from $finaltablef as A, $finaltableh as B where A.station=B.station and A.time=B.time and A.time >= '$psqlstarttime';"

echo /usr/bin/psql -U $user -d $database -c "insert into $finaltableff (station,name,time,lat,lon,regulation,drainagearea,contribarea,discharge,dobstype,stage,sobstype,detection,hourlyrise1,hourlyrise2,maxminstage,action,minor,moderate,major,q2,q5,q10,q25,q50,q100,q200,q500,risetime)  select A.station, A.name,A.time,A.lat,A.lon,A.regulation,A.drainagearea,A.contribarea,A.discharge,A.dobstype,A.stage,A.sobstype,'recurrence and rise' as method,B.hourlyrise1,B.hourlyrise2,B.maxminstage,A.action,A.minor,A.moderate,A.major,A.q2,A.q5,A.q10,A.q25,A.q50,A.q100,A.q200,A.q500,A.risetime from $finaltabler as A, $finaltableh as B where A.station=B.station and A.time=B.time and A.time >= '$psqlstarttime';"

echo /usr/bin/psql -U $user -d $database -c "insert into $finaltableff (station,name,time,lat,lon,regulation,drainagearea,contribarea,discharge,dobstype,stage,sobstype,detection,hourlyrise1,hourlyrise2,maxminstage,action,minor,moderate,major,q2,q5,q10,q25,q50,q100,q200,q500,risetime)  select A.station, A.name,A.time,A.lat,A.lon,A.regulation,A.drainagearea,A.contribarea,A.discharge,A.dobstype,A.stage,A.sobstype,'floodstage and rise' as method,B.hourlyrise1,B.hourlyrise2,B.maxminstage,A.action,A.minor,A.moderate,A.major,A.q2,A.q5,A.q10,A.q25,A.q50,A.q100,A.q200,A.q500,A.risetime from $finaltablef as A, $finaltableh as B where A.station=B.station and A.time=B.time and A.time >= '$psqlstarttime';"
#clean up by setting all negative values to -999
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltabler SET action = -999 WHERE action < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltabler SET minor = -999 WHERE minor < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltabler SET moderate = -999 WHERE moderate < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltabler SET major = -999 WHERE major < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltabler SET q2 = -999 WHERE q2 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltabler SET q5 = -999 WHERE q5 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltabler SET q10 = -999 WHERE q10 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltabler SET q25 = -999 WHERE q25 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltabler SET q50 = -999 WHERE q50 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltabler SET q100 = -999 WHERE q100 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltabler SET q200 = -999 WHERE q200 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltabler SET q500 = -999 WHERE q500 < 0;"

/usr/bin/psql -U $user -d $database -c "UPDATE $finaltablef SET action = -999 WHERE action < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltablef SET minor = -999 WHERE minor < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltablef SET moderate = -999 WHERE moderate < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltablef SET major = -999 WHERE major < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltablef SET q2 = -999 WHERE q2 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltablef SET q5 = -999 WHERE q5 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltablef SET q10 = -999 WHERE q10 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltablef SET q25 = -999 WHERE q25 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltablef SET q50 = -999 WHERE q50 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltablef SET q100 = -999 WHERE q100 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltablef SET q200 = -999 WHERE q200 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltablef SET q500 = -999 WHERE q500 < 0;"

/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableh SET action = -999 WHERE action < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableh SET minor = -999 WHERE minor < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableh SET moderate = -999 WHERE moderate < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableh SET major = -999 WHERE major < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableh SET q2 = -999 WHERE q2 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableh SET q5 = -999 WHERE q5 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableh SET q10 = -999 WHERE q10 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableh SET q25 = -999 WHERE q25 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableh SET q50 = -999 WHERE q50 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableh SET q100 = -999 WHERE q100 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableh SET q200 = -999 WHERE q200 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableh SET q500 = -999 WHERE q500 < 0;"

/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableff SET action = -999 WHERE action < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableff SET minor = -999 WHERE minor < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableff SET moderate = -999 WHERE moderate < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableff SET major = -999 WHERE major < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableff SET q2 = -999 WHERE q2 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableff SET q5 = -999 WHERE q5 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableff SET q10 = -999 WHERE q10 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableff SET q25 = -999 WHERE q25 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableff SET q50 = -999 WHERE q50 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableff SET q100 = -999 WHERE q100 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableff SET q200 = -999 WHERE q200 < 0;"
/usr/bin/psql -U $user -d $database -c "UPDATE $finaltableff SET q500 = -999 WHERE q500 < 0;"

#remove duplicate entries in databases
/usr/bin/psql -U $user -d $database -c "DELETE FROM $finaltabler USING $finaltabler alias WHERE $finaltabler.time = alias.time AND $finaltabler.lat = alias.lat AND $finaltabler.lon = alias.lon AND $finaltabler.station = alias.station AND $finaltabler.id < alias.id"
/usr/bin/psql -U $user -d $database -c "DELETE FROM $finaltableh USING $finaltableh alias WHERE $finaltableh.time = alias.time AND $finaltableh.lat = alias.lat AND $finaltableh.lon = alias.lon AND $finaltableh.station = alias.station AND $finaltableh.id < alias.id"
/usr/bin/psql -U $user -d $database -c "DELETE FROM $finaltablef USING $finaltablef alias WHERE $finaltablef.time = alias.time AND $finaltablef.lat = alias.lat AND $finaltablef.lon = alias.lon AND $finaltablef.station = alias.station AND $finaltablef.id < alias.id"
/usr/bin/psql -U $user -d $database -c "DELETE FROM $finaltableff USING $finaltableff alias WHERE $finaltableff.time = alias.time AND $finaltableff.lat = alias.lat AND $finaltableff.lon = alias.lon AND $finaltableff.station = alias.station AND $finaltableff.detection = alias.detection AND $finaltableff.id < alias.id"

date >> /hpc/home/hpc_test/bcosgrove/VERF.PROGRAMS/USGS/test/start.end.time.txt



