#!/usr/bin/env perl
use strict;
use warnings;
use DBI;
use DateTime::Format::Strptime;

# retrieve current data for use in establishing data query bounds
my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime();
     $year += 1900;
     $mon += 1;

#Postgres database interface code specifying database and table to link to along with commands
my $db=$ARGV[0];
my $table=$ARGV[1];
my $user = $ARGV[2];
my $startdate = $ARGV[3];
my $starttime = $ARGV[4];
my $enddate = $ARGV[5];
my $endtime = $ARGV[6];
my $magnitude = $ARGV[7];
#$pass = "pass";
#$host="localhost";

#connect to postgres database
my $dbh = DBI->connect( "dbi:Pg:dbname=$db", "$user" ) or die $DBI::errstr;
#prepare select command
my $stmt = qq(SELECT distinct on (station) * from $table where time between '$startdate $starttime' and '$enddate $endtime' ORDER by station,time);
print "SELECT distinct on (station) * from $table where time between '$startdate $starttime' and '$enddate $endtime' ORDER by station,time\n";
print "selected from $table between $startdate $starttime and $enddate $endtime\n";
#my $stmt = qq(SELECT * from $table where time between (timestamp '$year-$mon-$mday 18:00' - interval '24 hours') and '$year-$mon-$mday 12:00' ORDER by time);
my $sth = $dbh->prepare( $stmt );
my $rv = $sth->execute() or die $DBI::errstr;
if($rv < 0){
   print $DBI::errstr;
}


#create GEMPAK station table with original "A" point as well as four phantom stations B,C,D,E
#Phantom stations are necessary since GEMPAK requires 3 points for Barnes Analysis...otherwise
#it sets grid cell to undefined.  Phantoms are spaced +/- 1/100th degree latitude or longitude away
#from real observation point
#Also create GEMPAK data file along with non-phantom set of files
open (USGSSTATIONFILE, ">$table.station.tbl") or die;
open (USGSDATAFILE, ">$table.data.txt") or die;
open (USGSSTATIONFILENOPHAN, ">$table.station.nophan.tbl") or die;
open (USGSDATAFILENOPHAN, ">$table.data.nophan.txt") or die;

#initialize counter for use in unique station id in gempak station table
my $count=1;
#set all data points to end time of time window so that gempak can place all
#points on single image plot and not cycle through time
my $gemtimestring = $enddate."/".$endtime;
$gemtimestring =~ s/[:-]//g;
$gemtimestring = substr $gemtimestring, 2;
while(my @row = $sth->fetchrow_array()) {
#write out station table file
#B0000008 9999   RIVER FALLS                      AL US 3136  -8654  9999
# 570877 | 2014-05-20 15:42:00 |  44.74 |  -93.13 | flood minor
printf USGSSTATIONFILE "%s%07d %-6s %-32s %-2s %-2s %-05d %-06d %-5d\n","A",$count, 9999, $row[13], "UN", "US", $row[4]*100, $row[5]*100, 9999;
printf USGSSTATIONFILE "%s%07d %-6s %-32s %-2s %-2s %-05d %-06d %-5d\n","B",$count, 9999, $row[13], "UN", "US", $row[4]*100+1, $row[5]*100, 9999;
printf USGSSTATIONFILE "%s%07d %-6s %-32s %-2s %-2s %-05d %-06d %-5d\n","C",$count, 9999, $row[13], "UN", "US", $row[4]*100-1, $row[5]*100, 9999;
printf USGSSTATIONFILE "%s%07d %-6s %-32s %-2s %-2s %-05d %-06d %-5d\n","D",$count, 9999, $row[13], "UN", "US", $row[4]*100, $row[5]*100-1, 9999;
printf USGSSTATIONFILE "%s%07d %-6s %-32s %-2s %-2s %-05d %-06d %-5d\n","E",$count, 9999, $row[13], "UN", "US", $row[4]*100, $row[5]*100+1, 9999;

printf USGSSTATIONFILENOPHAN "%s%07d %-6s %-32s %-2s %-2s %-05d %-06d %-5d\n","A",$count, 9999, $row[13], "UN", "US", $row[4]*100, $row[5]*100, 9999;



#write out data file
printf USGSDATAFILE "PARM = MAGN\nSTID     DATTIM      MAGN\n" if $count==1;
printf USGSDATAFILE "%s%07d %-11s %6s\n", "A",$count, $gemtimestring, $magnitude;
printf USGSDATAFILE "%s%07d %-11s %6s\n", "B",$count, $gemtimestring, $magnitude;
printf USGSDATAFILE "%s%07d %-11s %6s\n", "C",$count, $gemtimestring, $magnitude;
printf USGSDATAFILE "%s%07d %-11s %6s\n", "D",$count, $gemtimestring, $magnitude;
printf USGSDATAFILE "%s%07d %-11s %6s\n", "E",$count, $gemtimestring, $magnitude;

printf USGSDATAFILENOPHAN "PARM = MAGN\nSTID     DATTIM      MAGN\n" if $count==1;
printf USGSDATAFILENOPHAN "%s%07d %-11s %6s\n", "A",$count, $gemtimestring, $magnitude;


$count=$count+1;
}
close USGSDATAFILE;
close USGSSTATIONFILE;
close USGSDATAFILENOPHAN;
close USGSSTATIONFILENOPHAN;






print "Operation done successfully\n";
$dbh->disconnect();


